package lt.bit.draudimas.controller;

import java.util.List;
import java.util.Optional;
import java.util.function.Function;

import javax.validation.Valid;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Example;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.repository.query.FluentQuery.FetchableFluentQuery;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

import lt.bit.draudimas.entities.Owner;
import lt.bit.draudimas.services.OwnerService;

@Controller
public class OwnerController {

	@Autowired
	OwnerService ownerService;
	
	@GetMapping("/")
	public String owners(Model model) {
		model.addAttribute("owners", ownerService.getOwners());
		return "owners";
	}
	
	@GetMapping("/newOwner")
	public String newOwner(Model model) {
		model.addAttribute("owner", new Owner());
		return "owner_new";
	}
	
	@PostMapping("/newOwner")
	public String saveOwner(
			@Valid 
			@ModelAttribute 
			Owner owner, 
			BindingResult result,
			Model model
			) {
		
		if (result.hasErrors()) {
			return "owner_new";
		}
		
		ownerService.addOwner(owner);
		return "redirect:/";
	}
	
	@GetMapping("/updateOwner")
	public String showOwner(@RequestParam("id") Integer id, Model model) {
		model.addAttribute("owner", ownerService.getOwnerById(id));
		return "owner_update";
	}
	
	@PostMapping("/updateOwner")
	public String updateOwner(@Valid @ModelAttribute Owner owner, BindingResult result, Model model) {
		if (result.hasErrors()) {
			return "owner_update";
		}
		ownerService.updateOwner(owner);
		return "redirect:/";
	}
	
	@GetMapping("/deleteOwner")
	public String deleteOwner(@RequestParam("id") Integer id) {
		ownerService.deleteOwner(id);
		return "redirect:/";
	}
}
